@@ -1,4 +1,4 @@
-require 'net/https'
+require 'puppet/ssl/openssl_loader'
 require 'digest/sha1'
 require 'uri'
 require 'puppet/util/http_proxy'
@@ -44,8 +44,8 @@ class Puppet::Forge
 
     # Return a Net::HTTPResponse read for this +path+.
     def make_http_request(path, io = nil)
-      Puppet.debug "HTTP GET #{@host}#{path}"
       request = get_request_object(@uri.path.chomp('/')+path)
+      Puppet.debug "HTTP GET #{@host}#{request.path}"
       return read_response(request, io)
     end
 
